@@ -411,6 +411,7 @@ _OptionalCreateMeetingRequestRequestTypeDef = TypedDict(
         "NotificationsConfiguration": NotificationsConfigurationTypeDef,
         "MeetingFeatures": MeetingFeaturesConfigurationTypeDef,
         "PrimaryMeetingId": str,
+        "TenantIds": Sequence[str],
     },
     total=False,
 )
@@ -438,6 +439,7 @@ _OptionalCreateMeetingWithAttendeesRequestRequestTypeDef = TypedDict(
         "MeetingFeatures": MeetingFeaturesConfigurationTypeDef,
         "NotificationsConfiguration": NotificationsConfigurationTypeDef,
         "PrimaryMeetingId": str,
+        "TenantIds": Sequence[str],
     },
     total=False,
 )
@@ -460,6 +462,7 @@ MeetingTypeDef = TypedDict(
         "MediaPlacement": MediaPlacementTypeDef,
         "MeetingFeatures": MeetingFeaturesConfigurationTypeDef,
         "PrimaryMeetingId": str,
+        "TenantIds": List[str],
     },
     total=False,
 )
